richardview.\_system package
============================

Submodules
----------

.. toctree::
   :maxdepth: 4

   richardview._system._automation_widget
   richardview._system._data_logging_widget
   richardview._system._serial_widget
   richardview._system._show_hide_widget

Module contents
---------------

.. automodule:: richardview._system
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:
